@@ -7,19 +7,19 @@ from typing import Any, Optional
 
 import dateutil.parser
 import pytest
-from pytest_mock import MockFixture
+from pytest_mock import MockerFixture
 
 import autosuspend
 
 
 class TestExecuteSuspend:
-    def test_smoke(self, mocker: MockFixture) -> None:
+    def test_smoke(self, mocker: MockerFixture) -> None:
         mock = mocker.patch("subprocess.check_call")
         command = ["foo", "bar"]
         autosuspend.execute_suspend(command, None)
         mock.assert_called_once_with(command, shell=True)
 
-    def test_call_exception(self, mocker: MockFixture) -> None:
+    def test_call_exception(self, mocker: MockerFixture) -> None:
         mock = mocker.patch("subprocess.check_call")
         command = ["foo", "bar"]
         mock.side_effect = subprocess.CalledProcessError(2, command)
@@ -33,7 +33,7 @@ class TestExecuteSuspend:
 
 
 class TestScheduleWakeup:
-    def test_smoke(self, mocker: MockFixture) -> None:
+    def test_smoke(self, mocker: MockerFixture) -> None:
         mock = mocker.patch("subprocess.check_call")
         dt = datetime.fromtimestamp(1525270801, timezone(timedelta(hours=4)))
         autosuspend.schedule_wakeup("echo {timestamp:.0f} {iso}", dt)
@@ -41,7 +41,7 @@ class TestScheduleWakeup:
             "echo 1525270801 2018-05-02T18:20:01+04:00", shell=True
         )
 
-    def test_call_exception(self, mocker: MockFixture) -> None:
+    def test_call_exception(self, mocker: MockerFixture) -> None:
         mock = mocker.patch("subprocess.check_call")
         mock.side_effect = subprocess.CalledProcessError(2, "foo")
 
@@ -54,21 +54,21 @@ class TestScheduleWakeup:
 
 
 class TestConfigureLogging:
-    def test_debug(self, mocker: MockFixture) -> None:
+    def test_debug(self, mocker: MockerFixture) -> None:
         mock = mocker.patch("logging.basicConfig")
 
         autosuspend.configure_logging(None, True)
 
         mock.assert_called_once_with(level=logging.DEBUG)
 
-    def test_standard(self, mocker: MockFixture) -> None:
+    def test_standard(self, mocker: MockerFixture) -> None:
         mock = mocker.patch("logging.basicConfig")
 
         autosuspend.configure_logging(None, False)
 
         mock.assert_called_once_with(level=logging.WARNING)
 
-    def test_file(self, mocker: MockFixture) -> None:
+    def test_file(self, mocker: MockerFixture) -> None:
         mock = mocker.patch("logging.config.fileConfig")
 
         # anything that is not a boolean is treated like a file
@@ -76,7 +76,7 @@ class TestConfigureLogging:
 
         mock.assert_called_once_with(42)
 
-    def test_file_fallback(self, mocker: MockFixture) -> None:
+    def test_file_fallback(self, mocker: MockerFixture) -> None:
         mock = mocker.patch("logging.config.fileConfig", side_effect=RuntimeError())
         mock_basic = mocker.patch("logging.basicConfig")
 
@@ -88,7 +88,7 @@ class TestConfigureLogging:
 
 
 class TestSetUpChecks:
-    def test_smoke(self, mocker: MockFixture) -> None:
+    def test_smoke(self, mocker: MockerFixture) -> None:
         mock_class = mocker.patch("autosuspend.checks.activity.Mpd")
         mock_class.create.return_value = mocker.MagicMock(
             spec=autosuspend.checks.Activity
@@ -109,7 +109,7 @@ class TestSetUpChecks:
 
         mock_class.create.assert_called_once_with("Foo", parser["check.Foo"])
 
-    def test_external_class(self, mocker: MockFixture) -> None:
+    def test_external_class(self, mocker: MockerFixture) -> None:
         mock_class = mocker.patch("os.path.TestCheck", create=True)
         mock_class.create.return_value = mocker.MagicMock(
             spec=autosuspend.checks.Activity
@@ -129,7 +129,7 @@ class TestSetUpChecks:
 
         mock_class.create.assert_called_once_with("Foo", parser["check.Foo"])
 
-    def test_not_enabled(self, mocker: MockFixture) -> None:
+    def test_not_enabled(self, mocker: MockerFixture) -> None:
         mock_class = mocker.patch("autosuspend.checks.activity.Mpd")
         mock_class.create.return_value = mocker.MagicMock(spec=autosuspend.Activity)
 
@@ -158,7 +158,7 @@ class TestSetUpChecks:
                 error_none=True,
             )
 
-    def test_not_enabled_continues_with_next(self, mocker: MockFixture) -> None:
+    def test_not_enabled_continues_with_next(self, mocker: MockerFixture) -> None:
         mock_mpd = mocker.patch("autosuspend.checks.activity.Mpd")
         mock_mpd.create.return_value = mocker.MagicMock(spec=autosuspend.Activity)
         mock_xidletime = mocker.patch("autosuspend.checks.activity.XIdleTime")
@@ -188,7 +188,7 @@ class TestSetUpChecks:
             == 1
         )
 
-    def test_no_such_class(self, mocker: MockFixture) -> None:
+    def test_no_such_class(self) -> None:
         parser = configparser.ConfigParser()
         parser.read_string(
             """
@@ -202,7 +202,7 @@ class TestSetUpChecks:
                 parser, "check", "activity", autosuspend.Activity  # type: ignore
             )
 
-    def test_not_a_check(self, mocker: MockFixture) -> None:
+    def test_not_a_check(self, mocker: MockerFixture) -> None:
         mock_class = mocker.patch("autosuspend.checks.activity.Mpd")
         mock_class.create.return_value = mocker.MagicMock()
 
@@ -222,7 +222,7 @@ class TestSetUpChecks:
 
         mock_class.create.assert_called_once_with("Foo", parser["check.Foo"])
 
-    def test_passwords_redacted(self, mocker: MockFixture, caplog: Any) -> None:
+    def test_passwords_redacted(self, mocker: MockerFixture, caplog: Any) -> None:
         mock_class = mocker.patch("autosuspend.checks.activity.Mpd")
         mock_class.create.return_value = mocker.MagicMock(
             spec=autosuspend.checks.Activity
@@ -247,10 +247,10 @@ class TestSetUpChecks:
 
 
 class TestExecuteChecks:
-    def test_no_checks(self, mocker: MockFixture) -> None:
+    def test_no_checks(self, mocker: MockerFixture) -> None:
         assert autosuspend.execute_checks([], False, mocker.MagicMock()) is False
 
-    def test_matches(self, mocker: MockFixture) -> None:
+    def test_matches(self, mocker: MockerFixture) -> None:
         matching_check = mocker.MagicMock(spec=autosuspend.Activity)
         matching_check.name = "foo"
         matching_check.check.return_value = "matches"
@@ -260,7 +260,7 @@ class TestExecuteChecks:
         )
         matching_check.check.assert_called_once_with()
 
-    def test_only_first_called(self, mocker: MockFixture) -> None:
+    def test_only_first_called(self, mocker: MockerFixture) -> None:
         matching_check = mocker.MagicMock(spec=autosuspend.Activity)
         matching_check.name = "foo"
         matching_check.check.return_value = "matches"
@@ -277,7 +277,7 @@ class TestExecuteChecks:
         matching_check.check.assert_called_once_with()
         second_check.check.assert_not_called()
 
-    def test_all_called(self, mocker: MockFixture) -> None:
+    def test_all_called(self, mocker: MockerFixture) -> None:
         matching_check = mocker.MagicMock(spec=autosuspend.Activity)
         matching_check.name = "foo"
         matching_check.check.return_value = "matches"
@@ -294,7 +294,7 @@ class TestExecuteChecks:
         matching_check.check.assert_called_once_with()
         second_check.check.assert_called_once_with()
 
-    def test_ignore_temporary_errors(self, mocker: MockFixture) -> None:
+    def test_ignore_temporary_errors(self, mocker: MockerFixture) -> None:
         matching_check = mocker.MagicMock(spec=autosuspend.Activity)
         matching_check.name = "foo"
         matching_check.check.side_effect = autosuspend.TemporaryCheckError()
@@ -313,7 +313,7 @@ class TestExecuteChecks:
 
 
 class TestExecuteWakeups:
-    def test_no_wakeups(self, mocker: MockFixture) -> None:
+    def test_no_wakeups(self, mocker: MockerFixture) -> None:
         assert (
             autosuspend.execute_wakeups(
                 [], datetime.now(timezone.utc), mocker.MagicMock()
@@ -321,7 +321,7 @@ class TestExecuteWakeups:
             is None
         )
 
-    def test_all_none(self, mocker: MockFixture) -> None:
+    def test_all_none(self, mocker: MockerFixture) -> None:
         wakeup = mocker.MagicMock(spec=autosuspend.Wakeup)
         wakeup.check.return_value = None
         assert (
@@ -336,7 +336,7 @@ class TestExecuteWakeups:
         [None, dateutil.parser.parse("20040605T090000Z")],
     )
     def test_skips_none_outdated_and_continues(
-        self, mocker: MockFixture, illegal: Optional[datetime]
+        self, mocker: MockerFixture, illegal: Optional[datetime]
     ) -> None:
         wakeup_none = mocker.MagicMock(spec=autosuspend.Wakeup)
         wakeup_none.check.return_value = illegal
@@ -354,7 +354,7 @@ class TestExecuteWakeups:
         )
         assert wakeup_none.check.called
 
-    def test_basic_return(self, mocker: MockFixture) -> None:
+    def test_basic_return(self, mocker: MockerFixture) -> None:
         wakeup = mocker.MagicMock(spec=autosuspend.Wakeup)
         now = datetime.now(timezone.utc)
         wakeup_time = now + timedelta(seconds=10)
@@ -364,7 +364,7 @@ class TestExecuteWakeups:
             == wakeup_time
         )
 
-    def test_soonest_taken(self, mocker: MockFixture) -> None:
+    def test_soonest_taken(self, mocker: MockerFixture) -> None:
         reference = datetime.now(timezone.utc)
         wakeup = mocker.MagicMock(spec=autosuspend.Wakeup)
         wakeup.check.return_value = reference + timedelta(seconds=20)
@@ -381,7 +381,7 @@ class TestExecuteWakeups:
             == earlier
         )
 
-    def test_ignore_temporary_errors(self, mocker: MockFixture) -> None:
+    def test_ignore_temporary_errors(self, mocker: MockerFixture) -> None:
         now = datetime.now(timezone.utc)
 
         wakeup = mocker.MagicMock(spec=autosuspend.Wakeup)
@@ -394,7 +394,7 @@ class TestExecuteWakeups:
             [wakeup, wakeup_error, wakeup_earlier], now, mocker.MagicMock()
         ) == now + timedelta(seconds=10)
 
-    def test_ignore_too_early(self, mocker: MockFixture) -> None:
+    def test_ignore_too_early(self, mocker: MockerFixture) -> None:
         now = datetime.now(timezone.utc)
         wakeup = mocker.MagicMock(spec=autosuspend.Wakeup)
         wakeup.check.return_value = now
@@ -408,7 +408,7 @@ class TestExecuteWakeups:
 
 
 class TestNotifySuspend:
-    def test_date(self, mocker: MockFixture) -> None:
+    def test_date(self, mocker: MockerFixture) -> None:
         mock = mocker.patch("subprocess.check_call")
         dt = datetime.fromtimestamp(1525270801, timezone(timedelta(hours=4)))
         autosuspend.notify_suspend("echo {timestamp:.0f} {iso}", "not this", dt)
@@ -416,23 +416,23 @@ class TestNotifySuspend:
             "echo 1525270801 2018-05-02T18:20:01+04:00", shell=True
         )
 
-    def test_date_no_command(self, mocker: MockFixture) -> None:
+    def test_date_no_command(self, mocker: MockerFixture) -> None:
         mock = mocker.patch("subprocess.check_call")
         dt = datetime.fromtimestamp(1525270801, timezone(timedelta(hours=4)))
         autosuspend.notify_suspend(None, "not this", dt)
         mock.assert_not_called()
 
-    def test_no_date(self, mocker: MockFixture) -> None:
+    def test_no_date(self, mocker: MockerFixture) -> None:
         mock = mocker.patch("subprocess.check_call")
         autosuspend.notify_suspend("echo {timestamp:.0f} {iso}", "echo nothing", None)
         mock.assert_called_once_with("echo nothing", shell=True)
 
-    def test_no_date_no_command(self, mocker: MockFixture) -> None:
+    def test_no_date_no_command(self, mocker: MockerFixture) -> None:
         mock = mocker.patch("subprocess.check_call")
         autosuspend.notify_suspend("echo {timestamp:.0f} {iso}", None, None)
         mock.assert_not_called()
 
-    def test_ignore_execution_errors(self, mocker: MockFixture, caplog: Any) -> None:
+    def test_ignore_execution_errors(self, mocker: MockerFixture, caplog: Any) -> None:
         mock = mocker.patch("subprocess.check_call")
         mock.side_effect = subprocess.CalledProcessError(2, "cmd")
         dt = datetime.fromtimestamp(1525270801, timezone(timedelta(hours=4)))
@@ -443,12 +443,12 @@ class TestNotifySuspend:
 
     def test_info_no_command(self, caplog: Any) -> None:
         with caplog.at_level(logging.INFO):
-            autosuspend.notify_suspend(None, None, datetime.now())
+            autosuspend.notify_suspend(None, None, datetime.now(tz=timezone.utc))
             assert "suitable" in caplog.text
 
 
 class TestConfigureProcessor:
-    def test_minimal_config(self, mocker: MockFixture) -> None:
+    def test_minimal_config(self, mocker: MockerFixture) -> None:
         parser = configparser.ConfigParser()
         parser.read_string(
             """
@@ -466,7 +466,7 @@ class TestConfigureProcessor:
         assert processor._all_activities
 
 
-def test_notify_and_suspend(mocker: MockFixture) -> None:
+def test_notify_and_suspend(mocker: MockerFixture) -> None:
     mock = mocker.patch("subprocess.check_call")
     dt = datetime.fromtimestamp(1525270801, timezone(timedelta(hours=4)))
     autosuspend.notify_and_suspend(
@@ -586,7 +586,7 @@ class TestProcessor:
         assert wakeup_fn.call_arg is None
 
     def test_wakeup_blocks_sleep(
-        self, mocker: MockFixture, sleep_fn: SleepFn, wakeup_fn: WakeupFn
+        self, mocker: MockerFixture, sleep_fn: SleepFn, wakeup_fn: WakeupFn
     ) -> None:
         start = datetime.now(timezone.utc)
         wakeup = mocker.MagicMock(spec=autosuspend.Wakeup)
@@ -604,7 +604,7 @@ class TestProcessor:
 
     def test_wakeup_exact_hit_does_not_block(
         self,
-        mocker: MockFixture,
+        mocker: MockerFixture,
         sleep_fn: SleepFn,
         wakeup_fn: WakeupFn,
     ) -> None:
@@ -623,7 +623,7 @@ class TestProcessor:
         assert wakeup_fn.call_arg is not None
 
     def test_wakeup_scheduled(
-        self, mocker: MockFixture, sleep_fn: SleepFn, wakeup_fn: WakeupFn
+        self, mocker: MockerFixture, sleep_fn: SleepFn, wakeup_fn: WakeupFn
     ) -> None:
         start = datetime.now(timezone.utc)
         wakeup = mocker.MagicMock(spec=autosuspend.Wakeup)
@@ -648,7 +648,7 @@ class TestProcessor:
         assert wakeup_fn.call_arg is None
 
     def test_wakeup_delta_blocks(
-        self, mocker: MockFixture, sleep_fn: SleepFn, wakeup_fn: WakeupFn
+        self, mocker: MockerFixture, sleep_fn: SleepFn, wakeup_fn: WakeupFn
     ) -> None:
         start = datetime.now(timezone.utc)
         wakeup = mocker.MagicMock(spec=autosuspend.Wakeup)
@@ -664,7 +664,7 @@ class TestProcessor:
         assert not sleep_fn.called
 
     def test_wakeup_delta_applied(
-        self, mocker: MockFixture, sleep_fn: SleepFn, wakeup_fn: WakeupFn
+        self, mocker: MockerFixture, sleep_fn: SleepFn, wakeup_fn: WakeupFn
     ) -> None:
         start = datetime.now(timezone.utc)
         wakeup = mocker.MagicMock(spec=autosuspend.Wakeup)
